==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/sk.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Upozornenia aktualizácií",
    "Could not start updater, please try the manual update" : "Nebolo možné spustiť aktualizátor, skúste prosím manuálnu aktualizáciu",
    "{version} is available. Get more information on how to update." : "{version} je dostupná. Získajte viac informácií o postupe aktualizácie.",
    "Channel updated" : "Kanál bol aktualizovaný",
    "Update to %1$s is available." : "Je dostupná aktualizácia na verziu %1$s.",
    "Update for %1$s to version %2$s is available." : "Pre %1$s je dostupná aktualizácia na verziu %2$s.",
    "Update for {app} to version %s is available." : "Pre {app} je dostupná aktualizácia na verziu %s.",
    "A new version is available: %s" : "Je dostupná nová verzia: %s",
    "Open updater" : "Otvoriť aktualizátor",
    "Download now" : "Stiahnuť teraz",
    "Your version is up to date." : "Vaša verzia je atuálna.",
    "Checked on %s" : "Skontrolované %s",
    "Update channel:" : "Aktualizačný kanál:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Vždy je možné prejsť na novšiu verziu / experimentálny kanál. Ale následne nie je možné prejsť naspäť na staršiu verziu / stabilnejší kanál.",
    "Notify members of the following groups about available updates:" : "Upozorňovať členov nasledujúcich skupín o dostupných aktualizáciach:",
    "Only notification for app updates are available." : "Sú dostupné upozornenia iba pre aktualizácie aplikácií.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Pre vybraný aktualizačný kanál budú priradené upozornenia pre server zastarané.",
    "The selected update channel does not support updates of the server." : "Vybraný aktualizačný kanál nepodporuje aktualizácie servera."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-12.0.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/sk.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Upozornenia aktualizácií",
    "Could not start updater, please try the manual update" : "Nebolo možné spustiť aktualizátor, skúste prosím manuálnu aktualizáciu",
    "{version} is available. Get more information on how to update." : "{version} je dostupná. Získajte viac informácií o postupe aktualizácie.",
    "Channel updated" : "Kanál bol aktualizovaný",
    "The update server could not be reached since %d days to check for new updates." : "Aktualizačný server je nedostupný %d dní pre kontrolu aktualizácií.",
    "Please check the Nextcloud and server log files for errors." : "Chyby skontrolujte prosím v logoch Nextcloud a webového servera",
    "Update to %1$s is available." : "Je dostupná aktualizácia na verziu %1$s.",
    "Update for %1$s to version %2$s is available." : "Pre %1$s je dostupná aktualizácia na verziu %2$s.",
    "Update for {app} to version %s is available." : "Pre {app} je dostupná aktualizácia na verziu %s.",
    "A new version is available: %s" : "Je dostupná nová verzia: %s",
    "Open updater" : "Otvoriť aktualizátor",
    "Download now" : "Stiahnuť teraz",
    "The update check is not yet finished. Please refresh the page." : "Kontrola aktualizácií ešte neskončila. Obnovte prosím stránku.",
    "Your version is up to date." : "Vaša verzia je atuálna.",
    "Checked on %s" : "Skontrolované %s",
    "A non-default update server is in use to be checked for updates:" : "Pre kontrolu aktualizácií sa používa iný než predvolený server:",
    "Update channel:" : "Aktualizačný kanál:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Vždy je možné prejsť na novšiu verziu / experimentálny kanál. Ale následne nie je možné prejsť naspäť na staršiu verziu / stabilnejší kanál.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Upozorňujeme, že po oficiálnom vydaní novej verzie môže chvíľu trvať, než sa tu objaví. Nové verzie medzi našich používateľov distribuujeme priebežne rozložené v čase a ak sa nájdu chyby, niekedy danú verziu preskočíme.",
    "Notify members of the following groups about available updates:" : "Upozorňovať členov nasledujúcich skupín o dostupných aktualizáciach:",
    "Only notification for app updates are available." : "Sú dostupné upozornenia iba pre aktualizácie aplikácií.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Pre vybraný aktualizačný kanál budú priradené upozornenia pre server zastarané.",
    "The selected update channel does not support updates of the server." : "Vybraný aktualizačný kanál nepodporuje aktualizácie servera."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
